==> jc-1.4.0.tar.gz: javax/swing/text/DefaultEditorKit__24BeepAction.h <==
// public class javax.swing.text.DefaultEditorKit$BeepAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 7f79ca6ebfd6a074 javax_swing_text_DefaultEditorKit__24BeepAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *);

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods	javax_swing_text_DefaultEditorKit__24BeepAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs	javax_swing_text_DefaultEditorKit__24BeepAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24BeepAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype _jc_javax_swing_text_DefaultEditorKit__24BeepAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24BeepAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24BeepAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/DefaultEditorKit__24BeepAction.h <==
// public class javax.swing.text.DefaultEditorKit$BeepAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 7f79ca6ebfd6a074 javax_swing_text_DefaultEditorKit__24BeepAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_
#define _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__24BeepAction$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vmethods	javax_swing_text_DefaultEditorKit__24BeepAction;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs {
    _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_refs	javax_swing_text_DefaultEditorKit__24BeepAction;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__24BeepAction$sub_nonrefs	javax_swing_text_DefaultEditorKit__24BeepAction;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__24BeepAction$object {
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__24BeepAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__24BeepAction$vtype _jc_javax_swing_text_DefaultEditorKit__24BeepAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__24BeepAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__24BeepAction$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__24BeepAction_H_ */
